@@ -67,6 +67,7 @@ def run_codespell(
         cwd=cwd,
         capture_output=True,
         encoding="utf-8",
+        check=False,
     )
     count = int(proc.stderr.split("\n")[-2])
     return count
@@ -89,9 +90,6 @@ def test_basic(
     with fname.open("a") as f:
         f.write("this is a test file\n")
     assert cs.main(fname) == 0, "good"
-    with fname.open("a") as f:
-        f.write("var = '\\nDoes not error on newline'\n")
-    assert cs.main(fname) == 0, "with string escape"
     with fname.open("a") as f:
         f.write("abandonned\n")
     assert cs.main(fname) == 1, "bad"
@@ -102,6 +100,14 @@ def test_basic(
         f.write("tim\ngonna\n")
     assert cs.main(fname) == 2, "with a name"
     assert cs.main("--builtin", "clear,rare,names,informal", fname) == 4
+    with fname.open("w") as f:  # overwrite the file
+        f.write("var = 'nwe must check codespell likes escapes nin strings'\n")
+    assert cs.main(fname) == 1, "checking our string escape test word is bad"
+    # the first one is missed because the apostrophe means its not currently
+    # treated as a word on its own
+    with fname.open("w") as f:  # overwrite the file
+        f.write("var = '\\nwe must check codespell likes escapes \\nin strings'\n")
+    assert cs.main(fname) == 0, "with string escape"
     result = cs.main(fname, "--builtin", "foo", std=True)
     assert isinstance(result, tuple)
     code, _, stderr = result
@@ -146,6 +152,22 @@ def test_basic(
     assert cs.main(tmp_path) == 0
 
 
+def test_default_word_parsing(
+    tmp_path: Path,
+    capsys: pytest.CaptureFixture[str],
+) -> None:
+    fname = tmp_path / "backtick"
+    with fname.open("a") as f:
+        f.write("`abandonned`\n")
+    assert cs.main(fname) == 1, "bad"
+
+    fname = tmp_path / "apostrophe"
+    fname.write_text("woudn't\n", encoding="utf-8")  # U+0027 (')
+    assert cs.main(fname) == 1, "misspelling containing typewriter apostrophe U+0027"
+    fname.write_text("woudn’t\n", encoding="utf-8")  # U+2019 (’)
+    assert cs.main(fname) == 1, "misspelling containing typographic apostrophe U+2019"
+
+
 def test_bad_glob(
     tmp_path: Path,
     capsys: pytest.CaptureFixture[str],
@@ -1038,14 +1060,16 @@ def test_config_toml(
     d.mkdir()
     (d / "bad.txt").write_text("abandonned donn\n")
     (d / "good.txt").write_text("good")
+    (d / "abandonned.txt").write_text("")
 
-    # Should fail when checking both.
-    result = cs.main(d, count=True, std=True)
+    # Should fail when checking all files.
+    result = cs.main(d, "--check-filenames", count=True, std=True)
     assert isinstance(result, tuple)
     code, stdout, _ = result
     # Code in this case is not exit code, but count of misspellings.
-    assert code == 2
+    assert code == 3
     assert "bad.txt" in stdout
+    assert "abandonned.txt" in stdout
 
     if kind == "cfg":
         conffile = tmp_path / "setup.cfg"
@@ -1067,16 +1091,18 @@ count =
             """\
 [tool.codespell]
 skip = 'bad.txt,whatever.txt'
-count = false
+check-filenames = false
+count = true
 """
         )
 
-    # Should pass when skipping bad.txt
-    result = cs.main(d, *args, count=True, std=True)
+    # Should pass when skipping bad.txt or abandonned.txt
+    result = cs.main(d, *args, std=True)
     assert isinstance(result, tuple)
     code, stdout, _ = result
     assert code == 0
     assert "bad.txt" not in stdout
+    assert "abandonned.txt" not in stdout
 
     # And both should automatically work if they're in cwd
     cwd = Path.cwd()
@@ -1089,6 +1115,7 @@ count = false
         os.chdir(cwd)
     assert code == 0
     assert "bad.txt" not in stdout
+    assert "abandonned.txt" not in stdout
 
 
 @contextlib.contextmanager
